<template>
  <div class="info-employee">
    <div class="header">
      <div class="title">
        <avatar size="40">
          <div class="per-name">
            {{ nick }}
          </div>
        </avatar>
        <span class="name">{{ title }}</span>
      </div>
      <div class="more" @click="showContent = !showContent">
        <span>{{ showContent ? "收起" : "更多" }}</span>
        <i class="icon" :class="[showContent ? 'icon-hide' : 'icon-more']"></i>
      </div>
    </div>
    <div v-show="showContent" class="content">
      <div class="info">
        <div class="detail">
          <span class="label">所属公司：</span>
          <span class="value value-link" @click="toCompany">{{ company }}</span>
        </div>
        <div class="detail">
          <span class="label">所属驻勤点：</span>
          <span class="value value-link" @click="toStation">{{ securityStationName }}</span>
        </div>
        <div class="detail">
          <span class="label">证件号码：</span>
          <span v-if="!idVisible" class="value">{{ idCardNoHide }}</span>
          <span v-if="idVisible" class="value">{{ idCardNo }}</span>
          <span class="visible" @click="idVisible = !idVisible">{{ idVisibleName }}</span>
        </div>
        <div class="detail">
          <span class="label">联系方式：</span>
          <span v-if="!concatVisible" class="value">{{ contactHide }}</span>
          <span v-if="concatVisible" class="value">{{ contact }}</span>
          <span class="visible" @click="concatVisible = !concatVisible">{{ contactVisibleName }}</span>
        </div>
        <div class="detail">
          <span class="label">实名认证：</span>
          <span class="value">{{ authenticatedStatusText }}</span>
        </div>
        <div class="detail">
          <span class="label">持证情况：</span>
          <span class="value">{{ certificateSituation }}</span>
        </div>
      </div>
      <div class="dispatch">
        <div class="title">指挥调度</div>
        <div class="btn-list">
          <van-button class="btn" plain hairline size="small" type="info" @click="character">文字</van-button>
          <van-button class="btn" plain hairline size="small" type="info" @click="callAudio">语音</van-button>
          <van-button class="btn" plain hairline size="small" type="info" @click="callVideo">视频调度</van-button>
          <van-button class="btn" plain hairline size="small" type="info" @click="railCk">周边调度</van-button>
          <van-button class="btn" plain hairline size="small" type="info" @click="videoLocalMute">视频上拉</van-button>
        </div>
      </div>
      <div class="dispatch">
        <div class="title">轨迹服务</div>
        <div class="btn-list">
          <van-button class="btn" plain hairline size="small" type="info" @click="queryTrack">轨迹查询</van-button>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import avatar from "@/components/avatar.vue";
import { Button } from "vant";

export default {
  name: "infoEmployee",
  components: {
    avatar,
    [Button.name]: Button,
  },
  props: {
    data: Object,
  },
  data() {
    return {
      showContent: false,
      idVisible: false,
      concatVisible: false,
    };
  },
  computed: {
    nick() {
      return this.data?.nameSlice || "";
    },
    title() {
      return `${this.data?.name} (${this.data?.dutyStatusText})`;
    },
    company() {
      return this.data?.companyName || "";
    },
    securityStationName() {
      return this.data?.securityStationName || "";
    },
    idCardNoHide() {
      return this.data?.idCardNoHide || "";
    },
    idCardNo() {
      return this.data?.idCardNo || "";
    },
    idVisibleName() {
      return this.idVisible ? "隐藏" : "显示";
    },
    contactHide() {
      return this.data?.contactHide || "";
    },
    contact() {
      return this.data?.contact || "";
    },
    contactVisibleName() {
      return this.concatVisible ? "隐藏" : "显示";
    },
    authenticatedStatusText() {
      return this.data?.authenticatedStatusText || "";
    },
    certificateSituation() {
      return this.data?.certificateSituation || "";
    },
  },
  methods: {
    toCompany() {
      this.$emit("toCompany", this.data, "employee");
    },
    toStation() {
      this.$emit("toStation", this.data, "employee");
    },
    character() {
      this.$emit("character");
    },
    callVideo() {
      this.$emit("callVideo", this.data);
    },
    callAudio() {
      this.$emit("callAudio", this.data);
    },
    railCk() {
      const data = {
        ...this.data,
        from: "employee",
      };
      this.$emit("dispatch", data);
    },
    videoLocalMute() {
      this.$emit("videoLocalMute", this.data);
    },
    queryTrack() {
      this.$emit("track", this.data);
    },
  },
};
</script>

<style scoped lang="less">
.info-employee {
  .header {
    width: 100%;
    height: 80px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    justify-content: space-between;
    .title {
      display: flex;
      align-items: center;
      .name {
        font-size: 14px;
        font-weight: 500;
        color: #303133;
        line-height: 22px;
        margin-left: 8px;
      }
      .per-name {
        height: 40px;
        width: 40px;
        background: #0e71ff;
        color: #fff;
        font-size: 12px;
        display: flex;
        align-items: center;
        justify-content: center;
      }
    }
    .more {
      width: 68px;
      height: 26px;
      border-radius: 24px;
      border: 1px solid #dcdfe6;
      display: flex;
      align-items: center;
      justify-content: space-between;
      padding: 0 10px;
      span {
        font-size: 14px;
        font-family: PingFang SC-Regular, PingFang SC;
        font-weight: 400;
        color: #303133;
      }
      .icon {
        display: block;
        width: 16px;
        height: 16px;
        &-hide {
          background: url("~@/assets/images/common/下.png") no-repeat;
          background-size: 100% 100%;
        }
        &-more {
          background: url("~@/assets/images/common/右.png") no-repeat;
          background-size: 100% 100%;
        }
      }
    }
  }
  .content {
    width: 100%;
    .info {
      width: 100%;
      padding: 12px 20px;
      .detail {
        width: 100%;
        display: flex;
        align-items: center;
        margin-bottom: 10px;
        &:last-child {
          margin-bottom: 0;
        }
        .label {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #909399;
        }

        .value {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #303133;
          &-link {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #0f71ff;
            text-decoration: underline;
          }
        }
        .visible {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #0f71ff;
          margin-left: 2px;
        }
      }
    }
    .dispatch {
      width: 100%;
      padding: 8px 20px;
      .title {
        font-size: 12px;
        line-height: 22px;
        font-family: PingFang SC-Medium, PingFang SC, serif;
        font-weight: 500;
        color: #3d3d3d;
        margin-bottom: 10px;
      }
      .btn-list {
        display: flex;
        flex-direction: row;
        flex-wrap: wrap;
        .btn {
          margin-bottom: 14px;
          margin-right: 20px;
          width: 88px;
          //border-radius: 6px 6px 6px 6px;
        }
      }
    }
  }
}
</style>
